package com.diaoyun.zion.master.util.spider;

import com.diaoyun.zion.chinafrica.enums.PlatformEnum;
import com.diaoyun.zion.chinafrica.vo.*;
import net.sf.json.JSONArray;
import net.sf.json.JSONObject;

import java.util.*;
import java.util.regex.Pattern;

import static com.diaoyun.zion.master.util.spider.SpiderUtil.exchangeRate;

/**
 * COACH(蔻驰) 爬虫数据解析
 * @see com.diaoyun.zion.chinafrica.bis.impl.CoachSpider
 * @author 爱酱油不爱醋
 */
public class CoachSpiderParse {

    /**
     * 格式化返回数据
     * @param dataMap 主要的Json数据
     * @return 格式化后的数据
     */
    public static ProductResponse formatProductResponse(JSONObject dataMap, String pId) {
        // 声明封装类
        ProductResponse productResponse = new ProductResponse();
        // 属性：Zara 的商品属性有颜色、尺码
        Map<String, Set<ProductProp>> productPropSet = new HashMap<>(16);
        // 原始价
        List<OriginalPrice> originalPriceList = new ArrayList<>();
        // 促销价格
        List<ProductPromotion> promotionList = new ArrayList<>();
        // 库存
        DynStock dynStock = new DynStock();
        // 其实数据没有包含确切的库存数，这里默认给足量的库存
        dynStock.setSellableQuantity(9999);

        // 取 data 节点对象
        JSONObject dataObj = dataMap.getJSONObject("data");

        //////////////////////////////////// 获取商品基本信息 ////////////////////////////
        ItemInfo itemInfo = new ItemInfo();
        itemInfo.setShopName(PlatformEnum.COACH.getLabel());
        itemInfo.setShopUrl("https://china.coach.com");
        itemInfo.setItemId(pId);
        itemInfo.setTitle(dataObj.getString("name"));
        //////////////////////////////////// 获取商品基本信息(图片下取)End /////////////////////////

        List<String> sizeNoList = new ArrayList<>();
        List<String> colorNoList = new ArrayList<>();
        // 取 attributes 节点数组
        JSONArray attributesArr = dataObj.getJSONArray("attributes");
        for (int i = 0; i < attributesArr.size(); i++) {
            ///////////////////////// 获取商品颜色属性 ////////////////////////////////////////////////////////////////
            // 0 位为颜色属性
            if (i == 0) {
                // 取 values 节点数组
                JSONArray valuesArr = attributesArr.getJSONObject(i).getJSONArray("values");

                Set<ProductProp> propSet = new HashSet<>(16);
                for (int j = 0; j < valuesArr.size(); j++) {
                    JSONObject valuesObj = valuesArr.getJSONObject(j);
                    // 获取图片路径
                    String imageUrl = valuesObj.getString("image");
                    // 设置商品基本信息的图片
                    if (i == 0) {
                        itemInfo.setPic(imageUrl);
                    }
                    ProductProp productPropColor = new ProductProp();
                    String colorNo = valuesObj.getString("value_index");
                    colorNoList.add(colorNo);
                    productPropColor.setPropId(colorNo);
                    productPropColor.setPropName(valuesObj.getString("label"));
                    productPropColor.setImage(imageUrl);
                    propSet.add(productPropColor);
                    if (productPropSet.get("颜色") == null) {
                        productPropSet.put("颜色", propSet);
                    } else {
                        Set<ProductProp> oldPropSet = productPropSet.get("颜色");
                        propSet.addAll(oldPropSet);
                        productPropSet.put("颜色", propSet);
                    }
                }
                ///////////////////////// 获取商品颜色属性End ////////////////////////////////////////////////////////////////

                ///////////////////////// 获取商品尺码属性 ////////////////////////////////////////////////////////////////
                // 1 位为尺寸属性(有的商品不一定会存在，如手提包)
            } else if (i == 1) {
                // 取 values 节点数组
                JSONArray valuesArr = attributesArr.getJSONObject(i).getJSONArray("values");

                Set<ProductProp> sizePropSet = new HashSet<>();
                for (int j = 0; j < valuesArr.size(); j++) {
                    JSONObject valuesObj = valuesArr.getJSONObject(j);
                    ProductProp productPropSize = new ProductProp();
                    String sizeNo = valuesObj.getString("value_index");
                    productPropSize.setPropId(sizeNo);
                    sizeNoList.add(sizeNo);
                    productPropSize.setPropName(valuesObj.getString("label"));
                    sizePropSet.add(productPropSize);
                    if (productPropSet.get("尺码") == null) {
                        productPropSet.put("尺码", sizePropSet);
                    } else {
                        Set<ProductProp> oldPropSet = productPropSet.get("尺码");
                        sizePropSet.addAll(oldPropSet);
                        productPropSet.put("尺码", sizePropSet);
                    }
                    ///////////////////////// 获取商品尺码属性 END/////////////////////////////////////////////////////
                }
            }

        }

        for (String colorNo : colorNoList) {
            for (String sizeNo : sizeNoList) {

                // 设置 skuStr
                String skuStr = ";" + colorNo + ";" + sizeNo + ";";

                // 设置：商品包含库存信息
                productResponse.setStockFlag(true);
                List<ProductSkuStock> productSkuStockList = dynStock.getProductSkuStockList();
                if (productSkuStockList == null) {
                    productSkuStockList = new ArrayList<>();
                }
                ProductSkuStock productSkuStock = new ProductSkuStock();
                // 设置：可用库存值，未有可用的库存数据
                productSkuStock.setSellableQuantity(999);
                // 设置：库存对应的id
                productSkuStock.setSkuStr(skuStr);
                productSkuStockList.add(productSkuStock);
                dynStock.setProductSkuStockList(productSkuStockList);
                //////////////////////////////////// 获取库存 END/////////////////////////////////////////

                //////////////////////////////////// 获取原始价 //////////////////////////////////
                // 获取商品的原始价(存在优惠价格)
                OriginalPrice originalPrice = new OriginalPrice();
                String fullPrice = Pattern.compile("[^0-9]").matcher(dataObj.getString("price")).replaceAll("").trim();
                // TODO 转换汇率，目前商品单位是人民币
                fullPrice = exchangeRate(fullPrice);
                productResponse.setPrice(fullPrice);
                productResponse.setSalePrice(fullPrice + "-" + fullPrice);
                originalPrice.setPrice(fullPrice);
                originalPrice.setSkuStr(skuStr);
                originalPriceList.add(originalPrice);
                //////////////////////////////////// 获取原始价 END //////////////////////////////////
            }
        }

        productResponse.setPropFlag(true);
        productResponse.setProductPropSet(productPropSet);
        productResponse.setPlatform(PlatformEnum.COACH.getValue());
        productResponse.setPromotionList(promotionList);
        productResponse.setOriginalPriceList(originalPriceList);
        productResponse.setItemInfo(itemInfo);
        productResponse.setDynStock(dynStock);
        return productResponse;
    }
}
